@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2009-2021 The Octave Project Developers
+// Copyright (C) 2009-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,8 +32,8 @@
 
 class Matrix;
 
-namespace octave
-{
+OCTAVE_NAMESPACE_BEGIN
+
   class display_info
   {
   public:
@@ -86,6 +86,7 @@ namespace octave
     // m_dpy_avail is false.
     std::string m_msg;
   };
-}
+
+OCTAVE_NAMESPACE_END
 
 #endif
