@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2020 The Octave Project Developers
+// Copyright (C) 1996-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,16 +32,16 @@
 extern "C" {
 #endif
 
-OCTAVE_NORETURN extern void
+OCTAVE_NORETURN extern OCTAVE_API void
 liboctave_fatal (const char *fmt, ...);
 
-OCTAVE_NORETURN extern
-void liboctave_fatal_with_id (const char *id, const char *fmt, ...);
+OCTAVE_NORETURN extern OCTAVE_API void
+liboctave_fatal_with_id (const char *id, const char *fmt, ...);
 
-extern void
+extern OCTAVE_API void
 liboctave_warning (const char *fmt, ...);
 
-extern void
+extern OCTAVE_API void
 liboctave_warning_with_id (const char *id, const char *fmt, ...);
 
 typedef void (*liboctave_error_handler) (const char *, ...);
@@ -57,30 +57,30 @@ typedef void (*liboctave_warning_with_id_handler) (const char *, const char *,
 /* Would be nice to make these pointers private, but we want to share
    them among all the liboctave classes. */
 OCTAVE_FORMAT_PRINTF (1, 2)
-OCTAVE_NORETURN OCTAVE_API extern liboctave_error_handler
+OCTAVE_NORETURN extern OCTAVE_API liboctave_error_handler
   current_liboctave_error_handler;
 
 OCTAVE_FORMAT_PRINTF (2, 3)
-OCTAVE_NORETURN OCTAVE_API extern liboctave_error_with_id_handler
+OCTAVE_NORETURN extern OCTAVE_API liboctave_error_with_id_handler
   current_liboctave_error_with_id_handler;
 
 OCTAVE_FORMAT_PRINTF (1, 2)
-OCTAVE_API extern liboctave_warning_handler current_liboctave_warning_handler;
+extern OCTAVE_API liboctave_warning_handler current_liboctave_warning_handler;
 
 OCTAVE_FORMAT_PRINTF (2, 3)
-OCTAVE_API extern liboctave_warning_with_id_handler
+extern OCTAVE_API liboctave_warning_with_id_handler
   current_liboctave_warning_with_id_handler;
 
-OCTAVE_API extern void
+extern OCTAVE_API void
 set_liboctave_error_handler (OCTAVE_NORETURN liboctave_error_handler f);
 
-OCTAVE_API extern void
+extern OCTAVE_API void
 set_liboctave_error_with_id_handler (OCTAVE_NORETURN liboctave_error_with_id_handler f);
 
-OCTAVE_API extern void
+extern OCTAVE_API void
 set_liboctave_warning_handler (liboctave_warning_handler f);
 
-OCTAVE_API extern void
+extern OCTAVE_API void
 set_liboctave_warning_with_id_handler (liboctave_warning_with_id_handler f);
 
 #if defined (__cplusplus)
